@@ -5,6 +5,7 @@
 # Copyright 2012 Steve English <steve.english@navetas.com>                     #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
+# Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 #                                                                              #
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
@@ -38,6 +39,7 @@ import github.UserKey
 import github.Issue
 import github.Event
 import github.Authorization
+import github.Notification
 
 
 class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
@@ -109,6 +111,14 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._email)
         return self._NoneIfNotSet(self._email)
 
+    @property
+    def events_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._events_url)
+        return self._NoneIfNotSet(self._events_url)
+
     @property
     def followers(self):
         """
@@ -117,6 +127,14 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._followers)
         return self._NoneIfNotSet(self._followers)
 
+    @property
+    def followers_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._followers_url)
+        return self._NoneIfNotSet(self._followers_url)
+
     @property
     def following(self):
         """
@@ -125,6 +143,22 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._following)
         return self._NoneIfNotSet(self._following)
 
+    @property
+    def following_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._following_url)
+        return self._NoneIfNotSet(self._following_url)
+
+    @property
+    def gists_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._gists_url)
+        return self._NoneIfNotSet(self._gists_url)
+
     @property
     def gravatar_id(self):
         """
@@ -181,6 +215,14 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._name)
         return self._NoneIfNotSet(self._name)
 
+    @property
+    def organizations_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._organizations_url)
+        return self._NoneIfNotSet(self._organizations_url)
+
     @property
     def owned_private_repos(self):
         """
@@ -221,6 +263,46 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._public_repos)
         return self._NoneIfNotSet(self._public_repos)
 
+    @property
+    def received_events_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._received_events_url)
+        return self._NoneIfNotSet(self._received_events_url)
+
+    @property
+    def repos_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._repos_url)
+        return self._NoneIfNotSet(self._repos_url)
+
+    @property
+    def site_admin(self):
+        """
+        :type: bool
+        """
+        self._completeIfNotSet(self._site_admin)
+        return self._NoneIfNotSet(self._site_admin)
+
+    @property
+    def starred_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._starred_url)
+        return self._NoneIfNotSet(self._starred_url)
+
+    @property
+    def subscriptions_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._subscriptions_url)
+        return self._NoneIfNotSet(self._subscriptions_url)
+
     @property
     def total_private_repos(self):
         """
@@ -237,6 +319,14 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._type)
         return self._NoneIfNotSet(self._type)
 
+    @property
+    def updated_at(self):
+        """
+        :type: datetime.datetime
+        """
+        self._completeIfNotSet(self._updated_at)
+        return self._NoneIfNotSet(self._updated_at)
+
     @property
     def url(self):
         """
@@ -256,8 +346,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             "/user/emails",
-            None,
-            post_parameters
+            input=post_parameters
         )
 
     def add_to_following(self, following):
@@ -269,9 +358,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(following, github.NamedUser.NamedUser), following
         headers, data = self._requester.requestJsonAndCheck(
             "PUT",
-            "/user/following/" + following._identity,
-            None,
-            None
+            "/user/following/" + following._identity
         )
 
     def add_to_starred(self, starred):
@@ -283,9 +370,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(starred, github.Repository.Repository), starred
         headers, data = self._requester.requestJsonAndCheck(
             "PUT",
-            "/user/starred/" + starred._identity,
-            None,
-            None
+            "/user/starred/" + starred._identity
         )
 
     def add_to_subscriptions(self, subscription):
@@ -297,9 +382,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(subscription, github.Repository.Repository), subscription
         headers, data = self._requester.requestJsonAndCheck(
             "PUT",
-            "/user/subscriptions/" + subscription._identity,
-            None,
-            None
+            "/user/subscriptions/" + subscription._identity
         )
 
     def add_to_watched(self, watched):
@@ -311,9 +394,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(watched, github.Repository.Repository), watched
         headers, data = self._requester.requestJsonAndCheck(
             "PUT",
-            "/user/watched/" + watched._identity,
-            None,
-            None
+            "/user/watched/" + watched._identity
         )
 
     def create_authorization(self, scopes=github.GithubObject.NotSet, note=github.GithubObject.NotSet, note_url=github.GithubObject.NotSet, client_id=github.GithubObject.NotSet, client_secret=github.GithubObject.NotSet):
@@ -345,10 +426,9 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             "/authorizations",
-            None,
-            post_parameters
+            input=post_parameters
         )
-        return github.Authorization.Authorization(self._requester, data, completed=True)
+        return github.Authorization.Authorization(self._requester, headers, data, completed=True)
 
     def create_fork(self, repo):
         """
@@ -359,11 +439,9 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(repo, github.Repository.Repository), repo
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
-            "/repos/" + repo.owner.login + "/" + repo.name + "/forks",
-            None,
-            None
+            "/repos/" + repo.owner.login + "/" + repo.name + "/forks"
         )
-        return github.Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, headers, data, completed=True)
 
     def create_gist(self, public, files, description=github.GithubObject.NotSet):
         """
@@ -385,10 +463,9 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             "/gists",
-            None,
-            post_parameters
+            input=post_parameters
         )
-        return github.Gist.Gist(self._requester, data, completed=True)
+        return github.Gist.Gist(self._requester, headers, data, completed=True)
 
     def create_key(self, title, key):
         """
@@ -406,10 +483,9 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             "/user/keys",
-            None,
-            post_parameters
+            input=post_parameters
         )
-        return github.UserKey.UserKey(self._requester, data, completed=True)
+        return github.UserKey.UserKey(self._requester, headers, data, completed=True)
 
     def create_repo(self, name, description=github.GithubObject.NotSet, homepage=github.GithubObject.NotSet, private=github.GithubObject.NotSet, has_issues=github.GithubObject.NotSet, has_wiki=github.GithubObject.NotSet, has_downloads=github.GithubObject.NotSet, auto_init=github.GithubObject.NotSet, gitignore_template=github.GithubObject.NotSet):
         """
@@ -456,10 +532,9 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             "/user/repos",
-            None,
-            post_parameters
+            input=post_parameters
         )
-        return github.Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, headers, data, completed=True)
 
     def edit(self, name=github.GithubObject.NotSet, email=github.GithubObject.NotSet, blog=github.GithubObject.NotSet, company=github.GithubObject.NotSet, location=github.GithubObject.NotSet, hireable=github.GithubObject.NotSet, bio=github.GithubObject.NotSet):
         """
@@ -498,8 +573,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "PATCH",
             "/user",
-            None,
-            post_parameters
+            input=post_parameters
         )
         self._useAttributes(data)
 
@@ -512,11 +586,9 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(id, (int, long)), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
-            "/authorizations/" + str(id),
-            None,
-            None
+            "/authorizations/" + str(id)
         )
-        return github.Authorization.Authorization(self._requester, data, completed=True)
+        return github.Authorization.Authorization(self._requester, headers, data, completed=True)
 
     def get_authorizations(self):
         """
@@ -537,9 +609,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         """
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
-            "/user/emails",
-            None,
-            None
+            "/user/emails"
         )
         return data
 
@@ -676,11 +746,9 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(id, (int, long)), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
-            "/user/keys/" + str(id),
-            None,
-            None
+            "/user/keys/" + str(id)
         )
-        return github.UserKey.UserKey(self._requester, data, completed=True)
+        return github.UserKey.UserKey(self._requester, headers, data, completed=True)
 
     def get_keys(self):
         """
@@ -703,15 +771,15 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(id, (str, unicode)), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
-            "/notifications/threads/" + id,
-            None,
-            None
+            "/notifications/threads/" + id
         )
-        return github.Notification.Notification(self._requester, data, completed=True)
+        return github.Notification.Notification(self._requester, headers, data, completed=True)
 
     def get_notifications(self, all=github.GithubObject.NotSet, participating=github.GithubObject.NotSet):
         """
         :calls: `GET /notifications <http://developer.github.com/v3/activity/notifications>`_
+        :param all: bool
+        :param participating: bool
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Notification.Notification`
         """
 
@@ -767,11 +835,9 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(name, (str, unicode)), name
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
-            "/repos/" + self.login + "/" + name,
-            None,
-            None
+            "/repos/" + self.login + "/" + name
         )
-        return github.Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, headers, data, completed=True)
 
     def get_repos(self, type=github.GithubObject.NotSet, sort=github.GithubObject.NotSet, direction=github.GithubObject.NotSet):
         """
@@ -855,9 +921,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(following, github.NamedUser.NamedUser), following
         status, headers, data = self._requester.requestJson(
             "GET",
-            "/user/following/" + following._identity,
-            None,
-            None
+            "/user/following/" + following._identity
         )
         return status == 204
 
@@ -870,9 +934,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(starred, github.Repository.Repository), starred
         status, headers, data = self._requester.requestJson(
             "GET",
-            "/user/starred/" + starred._identity,
-            None,
-            None
+            "/user/starred/" + starred._identity
         )
         return status == 204
 
@@ -885,9 +947,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(subscription, github.Repository.Repository), subscription
         status, headers, data = self._requester.requestJson(
             "GET",
-            "/user/subscriptions/" + subscription._identity,
-            None,
-            None
+            "/user/subscriptions/" + subscription._identity
         )
         return status == 204
 
@@ -900,9 +960,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(watched, github.Repository.Repository), watched
         status, headers, data = self._requester.requestJson(
             "GET",
-            "/user/watched/" + watched._identity,
-            None,
-            None
+            "/user/watched/" + watched._identity
         )
         return status == 204
 
@@ -917,8 +975,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
             "/user/emails",
-            None,
-            post_parameters
+            input=post_parameters
         )
 
     def remove_from_following(self, following):
@@ -930,9 +987,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(following, github.NamedUser.NamedUser), following
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
-            "/user/following/" + following._identity,
-            None,
-            None
+            "/user/following/" + following._identity
         )
 
     def remove_from_starred(self, starred):
@@ -944,9 +999,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(starred, github.Repository.Repository), starred
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
-            "/user/starred/" + starred._identity,
-            None,
-            None
+            "/user/starred/" + starred._identity
         )
 
     def remove_from_subscriptions(self, subscription):
@@ -958,9 +1011,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(subscription, github.Repository.Repository), subscription
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
-            "/user/subscriptions/" + subscription._identity,
-            None,
-            None
+            "/user/subscriptions/" + subscription._identity
         )
 
     def remove_from_watched(self, watched):
@@ -972,9 +1023,7 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(watched, github.Repository.Repository), watched
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
-            "/user/watched/" + watched._identity,
-            None,
-            None
+            "/user/watched/" + watched._identity
         )
 
     def _initAttributes(self):
@@ -986,8 +1035,12 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         self._created_at = github.GithubObject.NotSet
         self._disk_usage = github.GithubObject.NotSet
         self._email = github.GithubObject.NotSet
+        self._events_url = github.GithubObject.NotSet
         self._followers = github.GithubObject.NotSet
+        self._followers_url = github.GithubObject.NotSet
         self._following = github.GithubObject.NotSet
+        self._following_url = github.GithubObject.NotSet
+        self._gists_url = github.GithubObject.NotSet
         self._gravatar_id = github.GithubObject.NotSet
         self._hireable = github.GithubObject.NotSet
         self._html_url = github.GithubObject.NotSet
@@ -995,13 +1048,20 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         self._location = github.GithubObject.NotSet
         self._login = github.GithubObject.NotSet
         self._name = github.GithubObject.NotSet
+        self._organizations_url = github.GithubObject.NotSet
         self._owned_private_repos = github.GithubObject.NotSet
         self._plan = github.GithubObject.NotSet
         self._private_gists = github.GithubObject.NotSet
         self._public_gists = github.GithubObject.NotSet
         self._public_repos = github.GithubObject.NotSet
+        self._received_events_url = github.GithubObject.NotSet
+        self._repos_url = github.GithubObject.NotSet
+        self._site_admin = github.GithubObject.NotSet
+        self._starred_url = github.GithubObject.NotSet
+        self._subscriptions_url = github.GithubObject.NotSet
         self._total_private_repos = github.GithubObject.NotSet
         self._type = github.GithubObject.NotSet
+        self._updated_at = github.GithubObject.NotSet
         self._url = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
@@ -1029,12 +1089,24 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         if "email" in attributes:  # pragma no branch
             assert attributes["email"] is None or isinstance(attributes["email"], (str, unicode)), attributes["email"]
             self._email = attributes["email"]
+        if "events_url" in attributes:  # pragma no branch
+            assert attributes["events_url"] is None or isinstance(attributes["events_url"], (str, unicode)), attributes["events_url"]
+            self._events_url = attributes["events_url"]
         if "followers" in attributes:  # pragma no branch
             assert attributes["followers"] is None or isinstance(attributes["followers"], (int, long)), attributes["followers"]
             self._followers = attributes["followers"]
+        if "followers_url" in attributes:  # pragma no branch
+            assert attributes["followers_url"] is None or isinstance(attributes["followers_url"], (str, unicode)), attributes["followers_url"]
+            self._followers_url = attributes["followers_url"]
         if "following" in attributes:  # pragma no branch
             assert attributes["following"] is None or isinstance(attributes["following"], (int, long)), attributes["following"]
             self._following = attributes["following"]
+        if "following_url" in attributes:  # pragma no branch
+            assert attributes["following_url"] is None or isinstance(attributes["following_url"], (str, unicode)), attributes["following_url"]
+            self._following_url = attributes["following_url"]
+        if "gists_url" in attributes:  # pragma no branch
+            assert attributes["gists_url"] is None or isinstance(attributes["gists_url"], (str, unicode)), attributes["gists_url"]
+            self._gists_url = attributes["gists_url"]
         if "gravatar_id" in attributes:  # pragma no branch
             assert attributes["gravatar_id"] is None or isinstance(attributes["gravatar_id"], (str, unicode)), attributes["gravatar_id"]
             self._gravatar_id = attributes["gravatar_id"]
@@ -1056,12 +1128,15 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         if "name" in attributes:  # pragma no branch
             assert attributes["name"] is None or isinstance(attributes["name"], (str, unicode)), attributes["name"]
             self._name = attributes["name"]
+        if "organizations_url" in attributes:  # pragma no branch
+            assert attributes["organizations_url"] is None or isinstance(attributes["organizations_url"], (str, unicode)), attributes["organizations_url"]
+            self._organizations_url = attributes["organizations_url"]
         if "owned_private_repos" in attributes:  # pragma no branch
             assert attributes["owned_private_repos"] is None or isinstance(attributes["owned_private_repos"], (int, long)), attributes["owned_private_repos"]
             self._owned_private_repos = attributes["owned_private_repos"]
         if "plan" in attributes:  # pragma no branch
             assert attributes["plan"] is None or isinstance(attributes["plan"], dict), attributes["plan"]
-            self._plan = None if attributes["plan"] is None else github.Plan.Plan(self._requester, attributes["plan"], completed=False)
+            self._plan = None if attributes["plan"] is None else github.Plan.Plan(self._requester, self._headers, attributes["plan"], completed=False)
         if "private_gists" in attributes:  # pragma no branch
             assert attributes["private_gists"] is None or isinstance(attributes["private_gists"], (int, long)), attributes["private_gists"]
             self._private_gists = attributes["private_gists"]
@@ -1071,12 +1146,30 @@ class AuthenticatedUser(github.GithubObject.CompletableGithubObject):
         if "public_repos" in attributes:  # pragma no branch
             assert attributes["public_repos"] is None or isinstance(attributes["public_repos"], (int, long)), attributes["public_repos"]
             self._public_repos = attributes["public_repos"]
+        if "received_events_url" in attributes:  # pragma no branch
+            assert attributes["received_events_url"] is None or isinstance(attributes["received_events_url"], (str, unicode)), attributes["received_events_url"]
+            self._received_events_url = attributes["received_events_url"]
+        if "repos_url" in attributes:  # pragma no branch
+            assert attributes["repos_url"] is None or isinstance(attributes["repos_url"], (str, unicode)), attributes["repos_url"]
+            self._repos_url = attributes["repos_url"]
+        if "site_admin" in attributes:  # pragma no branch
+            assert attributes["site_admin"] is None or isinstance(attributes["site_admin"], bool), attributes["site_admin"]
+            self._site_admin = attributes["site_admin"]
+        if "starred_url" in attributes:  # pragma no branch
+            assert attributes["starred_url"] is None or isinstance(attributes["starred_url"], (str, unicode)), attributes["starred_url"]
+            self._starred_url = attributes["starred_url"]
+        if "subscriptions_url" in attributes:  # pragma no branch
+            assert attributes["subscriptions_url"] is None or isinstance(attributes["subscriptions_url"], (str, unicode)), attributes["subscriptions_url"]
+            self._subscriptions_url = attributes["subscriptions_url"]
         if "total_private_repos" in attributes:  # pragma no branch
             assert attributes["total_private_repos"] is None or isinstance(attributes["total_private_repos"], (int, long)), attributes["total_private_repos"]
             self._total_private_repos = attributes["total_private_repos"]
         if "type" in attributes:  # pragma no branch
             assert attributes["type"] is None or isinstance(attributes["type"], (str, unicode)), attributes["type"]
             self._type = attributes["type"]
+        if "updated_at" in attributes:  # pragma no branch
+            assert attributes["updated_at"] is None or isinstance(attributes["updated_at"], (str, unicode)), attributes["updated_at"]
+            self._updated_at = self._parseDatetime(attributes["updated_at"])
         if "url" in attributes:  # pragma no branch
             assert attributes["url"] is None or isinstance(attributes["url"], (str, unicode)), attributes["url"]
             self._url = attributes["url"]
