@@ -4,6 +4,7 @@
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
+# Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2013 martinqt <m.ki2@laposte.net>                                  #
 #                                                                              #
@@ -48,6 +49,14 @@ class Commit(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._author)
         return self._NoneIfNotSet(self._author)
 
+    @property
+    def comments_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._comments_url)
+        return self._NoneIfNotSet(self._comments_url)
+
     @property
     def commit(self):
         """
@@ -72,6 +81,14 @@ class Commit(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._files)
         return self._NoneIfNotSet(self._files)
 
+    @property
+    def html_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._html_url)
+        return self._NoneIfNotSet(self._html_url)
+
     @property
     def parents(self):
         """
@@ -129,10 +146,9 @@ class Commit(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             self.url + "/comments",
-            None,
-            post_parameters
+            input=post_parameters
         )
-        return github.CommitComment.CommitComment(self._requester, data, completed=True)
+        return github.CommitComment.CommitComment(self._requester, headers, data, completed=True)
 
     def create_status(self, state, target_url=github.GithubObject.NotSet, description=github.GithubObject.NotSet):
         """
@@ -155,10 +171,9 @@ class Commit(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             self._parentUrl(self._parentUrl(self.url)) + "/statuses/" + self.sha,
-            None,
-            post_parameters
+            input=post_parameters
         )
-        return github.CommitStatus.CommitStatus(self._requester, data, completed=True)
+        return github.CommitStatus.CommitStatus(self._requester, headers, data, completed=True)
 
     def get_comments(self):
         """
@@ -190,9 +205,11 @@ class Commit(github.GithubObject.CompletableGithubObject):
 
     def _initAttributes(self):
         self._author = github.GithubObject.NotSet
+        self._comments_url = github.GithubObject.NotSet
         self._commit = github.GithubObject.NotSet
         self._committer = github.GithubObject.NotSet
         self._files = github.GithubObject.NotSet
+        self._html_url = github.GithubObject.NotSet
         self._parents = github.GithubObject.NotSet
         self._sha = github.GithubObject.NotSet
         self._stats = github.GithubObject.NotSet
@@ -201,23 +218,29 @@ class Commit(github.GithubObject.CompletableGithubObject):
     def _useAttributes(self, attributes):
         if "author" in attributes:  # pragma no branch
             assert attributes["author"] is None or isinstance(attributes["author"], dict), attributes["author"]
-            self._author = None if attributes["author"] is None else github.NamedUser.NamedUser(self._requester, attributes["author"], completed=False)
+            self._author = None if attributes["author"] is None else github.NamedUser.NamedUser(self._requester, self._headers, attributes["author"], completed=False)
+        if "comments_url" in attributes:  # pragma no branch
+            assert attributes["comments_url"] is None or isinstance(attributes["comments_url"], (str, unicode)), attributes["comments_url"]
+            self._comments_url = attributes["comments_url"]
         if "commit" in attributes:  # pragma no branch
             assert attributes["commit"] is None or isinstance(attributes["commit"], dict), attributes["commit"]
-            self._commit = None if attributes["commit"] is None else github.GitCommit.GitCommit(self._requester, attributes["commit"], completed=False)
+            self._commit = None if attributes["commit"] is None else github.GitCommit.GitCommit(self._requester, self._headers, attributes["commit"], completed=False)
         if "committer" in attributes:  # pragma no branch
             assert attributes["committer"] is None or isinstance(attributes["committer"], dict), attributes["committer"]
-            self._committer = None if attributes["committer"] is None else github.NamedUser.NamedUser(self._requester, attributes["committer"], completed=False)
+            self._committer = None if attributes["committer"] is None else github.NamedUser.NamedUser(self._requester, self._headers, attributes["committer"], completed=False)
         if "files" in attributes:  # pragma no branch
             assert attributes["files"] is None or all(isinstance(element, dict) for element in attributes["files"]), attributes["files"]
             self._files = None if attributes["files"] is None else [
-                github.File.File(self._requester, element, completed=False)
+                github.File.File(self._requester, self._headers, element, completed=False)
                 for element in attributes["files"]
             ]
+        if "html_url" in attributes:  # pragma no branch
+            assert attributes["html_url"] is None or isinstance(attributes["html_url"], (str, unicode)), attributes["html_url"]
+            self._html_url = attributes["html_url"]
         if "parents" in attributes:  # pragma no branch
             assert attributes["parents"] is None or all(isinstance(element, dict) for element in attributes["parents"]), attributes["parents"]
             self._parents = None if attributes["parents"] is None else [
-                Commit(self._requester, element, completed=False)
+                Commit(self._requester, self._headers, element, completed=False)
                 for element in attributes["parents"]
             ]
         if "sha" in attributes:  # pragma no branch
@@ -225,7 +248,7 @@ class Commit(github.GithubObject.CompletableGithubObject):
             self._sha = attributes["sha"]
         if "stats" in attributes:  # pragma no branch
             assert attributes["stats"] is None or isinstance(attributes["stats"], dict), attributes["stats"]
-            self._stats = None if attributes["stats"] is None else github.CommitStats.CommitStats(self._requester, attributes["stats"], completed=False)
+            self._stats = None if attributes["stats"] is None else github.CommitStats.CommitStats(self._requester, self._headers, attributes["stats"], completed=False)
         if "url" in attributes:  # pragma no branch
             assert attributes["url"] is None or isinstance(attributes["url"], (str, unicode)), attributes["url"]
             self._url = attributes["url"]
