@@ -5,6 +5,7 @@
 # Copyright 2012 Steve English <steve.english@navetas.com>                     #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
+# Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 #                                                                              #
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
@@ -112,6 +113,14 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._email)
         return self._NoneIfNotSet(self._email)
 
+    @property
+    def events_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._events_url)
+        return self._NoneIfNotSet(self._events_url)
+
     @property
     def followers(self):
         """
@@ -120,6 +129,14 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._followers)
         return self._NoneIfNotSet(self._followers)
 
+    @property
+    def followers_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._followers_url)
+        return self._NoneIfNotSet(self._followers_url)
+
     @property
     def following(self):
         """
@@ -128,6 +145,22 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._following)
         return self._NoneIfNotSet(self._following)
 
+    @property
+    def following_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._following_url)
+        return self._NoneIfNotSet(self._following_url)
+
+    @property
+    def gists_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._gists_url)
+        return self._NoneIfNotSet(self._gists_url)
+
     @property
     def gravatar_id(self):
         """
@@ -184,6 +217,14 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._name)
         return self._NoneIfNotSet(self._name)
 
+    @property
+    def organizations_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._organizations_url)
+        return self._NoneIfNotSet(self._organizations_url)
+
     @property
     def owned_private_repos(self):
         """
@@ -224,6 +265,38 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._public_repos)
         return self._NoneIfNotSet(self._public_repos)
 
+    @property
+    def received_events_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._received_events_url)
+        return self._NoneIfNotSet(self._received_events_url)
+
+    @property
+    def repos_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._repos_url)
+        return self._NoneIfNotSet(self._repos_url)
+
+    @property
+    def starred_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._starred_url)
+        return self._NoneIfNotSet(self._starred_url)
+
+    @property
+    def subscriptions_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._subscriptions_url)
+        return self._NoneIfNotSet(self._subscriptions_url)
+
     @property
     def total_private_repos(self):
         """
@@ -240,6 +313,14 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._type)
         return self._NoneIfNotSet(self._type)
 
+    @property
+    def updated_at(self):
+        """
+        :type: datetime.datetime
+        """
+        self._completeIfNotSet(self._updated_at)
+        return self._NoneIfNotSet(self._updated_at)
+
     @property
     def url(self):
         """
@@ -248,6 +329,7 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._url)
         return self._NoneIfNotSet(self._url)
 
+    # v2: Remove this method
     def create_gist(self, public, files, description=github.GithubObject.NotSet):
         """
         :calls: `POST /users/:user/gists <http://developer.github.com/v3/todo>`_
@@ -268,10 +350,9 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             self.url + "/gists",
-            None,
-            post_parameters
+            input=post_parameters
         )
-        return github.Gist.Gist(self._requester, data, completed=True)
+        return github.Gist.Gist(self._requester, headers, data, completed=True)
 
     def get_events(self):
         """
@@ -390,11 +471,9 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         assert isinstance(name, (str, unicode)), name
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
-            "/repos/" + self.login + "/" + name,
-            None,
-            None
+            "/repos/" + self.login + "/" + name
         )
-        return github.Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, headers, data, completed=True)
 
     def get_repos(self, type=github.GithubObject.NotSet):
         """
@@ -449,6 +528,19 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
             None
         )
 
+    def has_in_following(self, following):
+        """
+        :calls: `GET /users/:user/following/:target_user <http://developer.github.com/v3/users/followers/#check-if-one-user-follows-another>`_
+        :param following: :class:`github.NamedUser.NamedUser`
+        :rtype: bool
+        """
+        assert isinstance(following, github.NamedUser.NamedUser), following
+        status, headers, data = self._requester.requestJson(
+            "GET",
+            self.url + "/following/" + following._identity
+        )
+        return status == 204
+
     @property
     def _identity(self):
         return self.login
@@ -463,8 +555,12 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._created_at = github.GithubObject.NotSet
         self._disk_usage = github.GithubObject.NotSet
         self._email = github.GithubObject.NotSet
+        self._events_url = github.GithubObject.NotSet
         self._followers = github.GithubObject.NotSet
+        self._followers_url = github.GithubObject.NotSet
         self._following = github.GithubObject.NotSet
+        self._following_url = github.GithubObject.NotSet
+        self._gists_url = github.GithubObject.NotSet
         self._gravatar_id = github.GithubObject.NotSet
         self._hireable = github.GithubObject.NotSet
         self._html_url = github.GithubObject.NotSet
@@ -472,13 +568,19 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         self._location = github.GithubObject.NotSet
         self._login = github.GithubObject.NotSet
         self._name = github.GithubObject.NotSet
+        self._organizations_url = github.GithubObject.NotSet
         self._owned_private_repos = github.GithubObject.NotSet
         self._plan = github.GithubObject.NotSet
         self._private_gists = github.GithubObject.NotSet
         self._public_gists = github.GithubObject.NotSet
         self._public_repos = github.GithubObject.NotSet
+        self._received_events_url = github.GithubObject.NotSet
+        self._repos_url = github.GithubObject.NotSet
+        self._starred_url = github.GithubObject.NotSet
+        self._subscriptions_url = github.GithubObject.NotSet
         self._total_private_repos = github.GithubObject.NotSet
         self._type = github.GithubObject.NotSet
+        self._updated_at = github.GithubObject.NotSet
         self._url = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
@@ -509,12 +611,24 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         if "email" in attributes:  # pragma no branch
             assert attributes["email"] is None or isinstance(attributes["email"], (str, unicode)), attributes["email"]
             self._email = attributes["email"]
+        if "events_url" in attributes:  # pragma no branch
+            assert attributes["events_url"] is None or isinstance(attributes["events_url"], (str, unicode)), attributes["events_url"]
+            self._events_url = attributes["events_url"]
         if "followers" in attributes:  # pragma no branch
             assert attributes["followers"] is None or isinstance(attributes["followers"], (int, long)), attributes["followers"]
             self._followers = attributes["followers"]
+        if "followers_url" in attributes:  # pragma no branch
+            assert attributes["followers_url"] is None or isinstance(attributes["followers_url"], (str, unicode)), attributes["followers_url"]
+            self._followers_url = attributes["followers_url"]
         if "following" in attributes:  # pragma no branch
             assert attributes["following"] is None or isinstance(attributes["following"], (int, long)), attributes["following"]
             self._following = attributes["following"]
+        if "following_url" in attributes:  # pragma no branch
+            assert attributes["following_url"] is None or isinstance(attributes["following_url"], (str, unicode)), attributes["following_url"]
+            self._following_url = attributes["following_url"]
+        if "gists_url" in attributes:  # pragma no branch
+            assert attributes["gists_url"] is None or isinstance(attributes["gists_url"], (str, unicode)), attributes["gists_url"]
+            self._gists_url = attributes["gists_url"]
         if "gravatar_id" in attributes:  # pragma no branch
             assert attributes["gravatar_id"] is None or isinstance(attributes["gravatar_id"], (str, unicode)), attributes["gravatar_id"]
             self._gravatar_id = attributes["gravatar_id"]
@@ -536,12 +650,15 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         if "name" in attributes:  # pragma no branch
             assert attributes["name"] is None or isinstance(attributes["name"], (str, unicode)), attributes["name"]
             self._name = attributes["name"]
+        if "organizations_url" in attributes:  # pragma no branch
+            assert attributes["organizations_url"] is None or isinstance(attributes["organizations_url"], (str, unicode)), attributes["organizations_url"]
+            self._organizations_url = attributes["organizations_url"]
         if "owned_private_repos" in attributes:  # pragma no branch
             assert attributes["owned_private_repos"] is None or isinstance(attributes["owned_private_repos"], (int, long)), attributes["owned_private_repos"]
             self._owned_private_repos = attributes["owned_private_repos"]
         if "plan" in attributes:  # pragma no branch
             assert attributes["plan"] is None or isinstance(attributes["plan"], dict), attributes["plan"]
-            self._plan = None if attributes["plan"] is None else github.Plan.Plan(self._requester, attributes["plan"], completed=False)
+            self._plan = None if attributes["plan"] is None else github.Plan.Plan(self._requester, self._headers, attributes["plan"], completed=False)
         if "private_gists" in attributes:  # pragma no branch
             assert attributes["private_gists"] is None or isinstance(attributes["private_gists"], (int, long)), attributes["private_gists"]
             self._private_gists = attributes["private_gists"]
@@ -551,12 +668,27 @@ class NamedUser(github.GithubObject.CompletableGithubObject):
         if "public_repos" in attributes:  # pragma no branch
             assert attributes["public_repos"] is None or isinstance(attributes["public_repos"], (int, long)), attributes["public_repos"]
             self._public_repos = attributes["public_repos"]
+        if "received_events_url" in attributes:  # pragma no branch
+            assert attributes["received_events_url"] is None or isinstance(attributes["received_events_url"], (str, unicode)), attributes["received_events_url"]
+            self._received_events_url = attributes["received_events_url"]
+        if "repos_url" in attributes:  # pragma no branch
+            assert attributes["repos_url"] is None or isinstance(attributes["repos_url"], (str, unicode)), attributes["repos_url"]
+            self._repos_url = attributes["repos_url"]
+        if "starred_url" in attributes:  # pragma no branch
+            assert attributes["starred_url"] is None or isinstance(attributes["starred_url"], (str, unicode)), attributes["starred_url"]
+            self._starred_url = attributes["starred_url"]
+        if "subscriptions_url" in attributes:  # pragma no branch
+            assert attributes["subscriptions_url"] is None or isinstance(attributes["subscriptions_url"], (str, unicode)), attributes["subscriptions_url"]
+            self._subscriptions_url = attributes["subscriptions_url"]
         if "total_private_repos" in attributes:  # pragma no branch
             assert attributes["total_private_repos"] is None or isinstance(attributes["total_private_repos"], (int, long)), attributes["total_private_repos"]
             self._total_private_repos = attributes["total_private_repos"]
         if "type" in attributes:  # pragma no branch
             assert attributes["type"] is None or isinstance(attributes["type"], (str, unicode)), attributes["type"]
             self._type = attributes["type"]
+        if "updated_at" in attributes:  # pragma no branch
+            assert attributes["updated_at"] is None or isinstance(attributes["updated_at"], (str, unicode)), attributes["updated_at"]
+            self._updated_at = self._parseDatetime(attributes["updated_at"])
         if "url" in attributes:  # pragma no branch
             assert attributes["url"] is None or isinstance(attributes["url"], (str, unicode)), attributes["url"]
             self._url = attributes["url"]
