@@ -5,6 +5,7 @@
 # Copyright 2012 Michael Stead <michael.stead@gmail.com>                       #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
+# Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2013 martinqt <m.ki2@laposte.net>                                  #
 #                                                                              #
@@ -98,6 +99,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._comments)
         return self._NoneIfNotSet(self._comments)
 
+    @property
+    def comments_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._comments_url)
+        return self._NoneIfNotSet(self._comments_url)
+
     @property
     def commits(self):
         """
@@ -106,6 +115,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._commits)
         return self._NoneIfNotSet(self._commits)
 
+    @property
+    def commits_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._commits_url)
+        return self._NoneIfNotSet(self._commits_url)
+
     @property
     def created_at(self):
         """
@@ -162,6 +179,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._issue_url)
         return self._NoneIfNotSet(self._issue_url)
 
+    @property
+    def merge_commit_sha(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._merge_commit_sha)
+        return self._NoneIfNotSet(self._merge_commit_sha)
+
     @property
     def mergeable(self):
         """
@@ -170,6 +195,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._mergeable)
         return self._NoneIfNotSet(self._mergeable)
 
+    @property
+    def mergeable_state(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._mergeable_state)
+        return self._NoneIfNotSet(self._mergeable_state)
+
     @property
     def merged(self):
         """
@@ -194,6 +227,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._merged_by)
         return self._NoneIfNotSet(self._merged_by)
 
+    @property
+    def milestone(self):
+        """
+        :type: :class:`github.Milestone.Milestone`
+        """
+        self._completeIfNotSet(self._milestone)
+        return self._NoneIfNotSet(self._milestone)
+
     @property
     def number(self):
         """
@@ -210,6 +251,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._patch_url)
         return self._NoneIfNotSet(self._patch_url)
 
+    @property
+    def review_comment_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._review_comment_url)
+        return self._NoneIfNotSet(self._review_comment_url)
+
     @property
     def review_comments(self):
         """
@@ -218,6 +267,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._review_comments)
         return self._NoneIfNotSet(self._review_comments)
 
+    @property
+    def review_comments_url(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._review_comments_url)
+        return self._NoneIfNotSet(self._review_comments_url)
+
     @property
     def state(self):
         """
@@ -291,10 +348,9 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             self.url + "/comments",
-            None,
-            post_parameters
+            input=post_parameters
         )
-        return github.PullRequestComment.PullRequestComment(self._requester, data, completed=True)
+        return github.PullRequestComment.PullRequestComment(self._requester, headers, data, completed=True)
 
     def create_issue_comment(self, body):
         """
@@ -309,10 +365,9 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
             self._parentUrl(self._parentUrl(self.url)) + "/issues/" + str(self.number) + "/comments",
-            None,
-            post_parameters
+            input=post_parameters
         )
-        return github.IssueComment.IssueComment(self._requester, data, completed=True)
+        return github.IssueComment.IssueComment(self._requester, headers, data, completed=True)
 
     def edit(self, title=github.GithubObject.NotSet, body=github.GithubObject.NotSet, state=github.GithubObject.NotSet):
         """
@@ -335,8 +390,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "PATCH",
             self.url,
-            None,
-            post_parameters
+            input=post_parameters
         )
         self._useAttributes(data)
 
@@ -357,11 +411,9 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         assert isinstance(id, (int, long)), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
-            self._parentUrl(self.url) + "/comments/" + str(id),
-            None,
-            None
+            self._parentUrl(self.url) + "/comments/" + str(id)
         )
-        return github.PullRequestComment.PullRequestComment(self._requester, data, completed=True)
+        return github.PullRequestComment.PullRequestComment(self._requester, headers, data, completed=True)
 
     def get_comments(self):
         """
@@ -415,11 +467,9 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         assert isinstance(id, (int, long)), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
-            self._parentUrl(self._parentUrl(self.url)) + "/issues/comments/" + str(id),
-            None,
-            None
+            self._parentUrl(self._parentUrl(self.url)) + "/issues/comments/" + str(id)
         )
-        return github.IssueComment.IssueComment(self._requester, data, completed=True)
+        return github.IssueComment.IssueComment(self._requester, headers, data, completed=True)
 
     def get_issue_comments(self):
         """
@@ -440,9 +490,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         """
         status, headers, data = self._requester.requestJson(
             "GET",
-            self.url + "/merge",
-            None,
-            None
+            self.url + "/merge"
         )
         return status == 204
 
@@ -459,10 +507,9 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck(
             "PUT",
             self.url + "/merge",
-            None,
-            post_parameters
+            input=post_parameters
         )
-        return github.PullRequestMergeStatus.PullRequestMergeStatus(self._requester, data, completed=True)
+        return github.PullRequestMergeStatus.PullRequestMergeStatus(self._requester, headers, data, completed=True)
 
     def _initAttributes(self):
         self._additions = github.GithubObject.NotSet
@@ -472,7 +519,9 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         self._changed_files = github.GithubObject.NotSet
         self._closed_at = github.GithubObject.NotSet
         self._comments = github.GithubObject.NotSet
+        self._comments_url = github.GithubObject.NotSet
         self._commits = github.GithubObject.NotSet
+        self._commits_url = github.GithubObject.NotSet
         self._created_at = github.GithubObject.NotSet
         self._deletions = github.GithubObject.NotSet
         self._diff_url = github.GithubObject.NotSet
@@ -480,13 +529,18 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         self._html_url = github.GithubObject.NotSet
         self._id = github.GithubObject.NotSet
         self._issue_url = github.GithubObject.NotSet
+        self._merge_commit_sha = github.GithubObject.NotSet
         self._mergeable = github.GithubObject.NotSet
+        self._mergeable_state = github.GithubObject.NotSet
         self._merged = github.GithubObject.NotSet
         self._merged_at = github.GithubObject.NotSet
         self._merged_by = github.GithubObject.NotSet
+        self._milestone = github.GithubObject.NotSet
         self._number = github.GithubObject.NotSet
         self._patch_url = github.GithubObject.NotSet
+        self._review_comment_url = github.GithubObject.NotSet
         self._review_comments = github.GithubObject.NotSet
+        self._review_comments_url = github.GithubObject.NotSet
         self._state = github.GithubObject.NotSet
         self._title = github.GithubObject.NotSet
         self._updated_at = github.GithubObject.NotSet
@@ -499,10 +553,10 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             self._additions = attributes["additions"]
         if "assignee" in attributes:  # pragma no branch
             assert attributes["assignee"] is None or isinstance(attributes["assignee"], dict), attributes["assignee"]
-            self._assignee = None if attributes["assignee"] is None else github.NamedUser.NamedUser(self._requester, attributes["assignee"], completed=False)
+            self._assignee = None if attributes["assignee"] is None else github.NamedUser.NamedUser(self._requester, self._headers, attributes["assignee"], completed=False)
         if "base" in attributes:  # pragma no branch
             assert attributes["base"] is None or isinstance(attributes["base"], dict), attributes["base"]
-            self._base = None if attributes["base"] is None else github.PullRequestPart.PullRequestPart(self._requester, attributes["base"], completed=False)
+            self._base = None if attributes["base"] is None else github.PullRequestPart.PullRequestPart(self._requester, self._headers, attributes["base"], completed=False)
         if "body" in attributes:  # pragma no branch
             assert attributes["body"] is None or isinstance(attributes["body"], (str, unicode)), attributes["body"]
             self._body = attributes["body"]
@@ -515,9 +569,15 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         if "comments" in attributes:  # pragma no branch
             assert attributes["comments"] is None or isinstance(attributes["comments"], (int, long)), attributes["comments"]
             self._comments = attributes["comments"]
+        if "comments_url" in attributes:  # pragma no branch
+            assert attributes["comments_url"] is None or isinstance(attributes["comments_url"], (str, unicode)), attributes["comments_url"]
+            self._comments_url = attributes["comments_url"]
         if "commits" in attributes:  # pragma no branch
             assert attributes["commits"] is None or isinstance(attributes["commits"], (int, long)), attributes["commits"]
             self._commits = attributes["commits"]
+        if "commits_url" in attributes:  # pragma no branch
+            assert attributes["commits_url"] is None or isinstance(attributes["commits_url"], (str, unicode)), attributes["commits_url"]
+            self._commits_url = attributes["commits_url"]
         if "created_at" in attributes:  # pragma no branch
             assert attributes["created_at"] is None or isinstance(attributes["created_at"], (str, unicode)), attributes["created_at"]
             self._created_at = self._parseDatetime(attributes["created_at"])
@@ -529,7 +589,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             self._diff_url = attributes["diff_url"]
         if "head" in attributes:  # pragma no branch
             assert attributes["head"] is None or isinstance(attributes["head"], dict), attributes["head"]
-            self._head = None if attributes["head"] is None else github.PullRequestPart.PullRequestPart(self._requester, attributes["head"], completed=False)
+            self._head = None if attributes["head"] is None else github.PullRequestPart.PullRequestPart(self._requester, self._headers, attributes["head"], completed=False)
         if "html_url" in attributes:  # pragma no branch
             assert attributes["html_url"] is None or isinstance(attributes["html_url"], (str, unicode)), attributes["html_url"]
             self._html_url = attributes["html_url"]
@@ -539,9 +599,15 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         if "issue_url" in attributes:  # pragma no branch
             assert attributes["issue_url"] is None or isinstance(attributes["issue_url"], (str, unicode)), attributes["issue_url"]
             self._issue_url = attributes["issue_url"]
+        if "merge_commit_sha" in attributes:  # pragma no branch
+            assert attributes["merge_commit_sha"] is None or isinstance(attributes["merge_commit_sha"], (str, unicode)), attributes["merge_commit_sha"]
+            self._merge_commit_sha = attributes["merge_commit_sha"]
         if "mergeable" in attributes:  # pragma no branch
             assert attributes["mergeable"] is None or isinstance(attributes["mergeable"], bool), attributes["mergeable"]
             self._mergeable = attributes["mergeable"]
+        if "mergeable_state" in attributes:  # pragma no branch
+            assert attributes["mergeable_state"] is None or isinstance(attributes["mergeable_state"], (str, unicode)), attributes["mergeable_state"]
+            self._mergeable_state = attributes["mergeable_state"]
         if "merged" in attributes:  # pragma no branch
             assert attributes["merged"] is None or isinstance(attributes["merged"], bool), attributes["merged"]
             self._merged = attributes["merged"]
@@ -550,16 +616,25 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             self._merged_at = self._parseDatetime(attributes["merged_at"])
         if "merged_by" in attributes:  # pragma no branch
             assert attributes["merged_by"] is None or isinstance(attributes["merged_by"], dict), attributes["merged_by"]
-            self._merged_by = None if attributes["merged_by"] is None else github.NamedUser.NamedUser(self._requester, attributes["merged_by"], completed=False)
+            self._merged_by = None if attributes["merged_by"] is None else github.NamedUser.NamedUser(self._requester, self._headers, attributes["merged_by"], completed=False)
+        if "milestone" in attributes:  # pragma no branch
+            assert attributes["milestone"] is None or isinstance(attributes["milestone"], dict), attributes["milestone"]
+            self._milestone = None if attributes["milestone"] is None else github.Milestone.Milestone(self._requester, self._headers, attributes["milestone"], completed=False)
         if "number" in attributes:  # pragma no branch
             assert attributes["number"] is None or isinstance(attributes["number"], (int, long)), attributes["number"]
             self._number = attributes["number"]
         if "patch_url" in attributes:  # pragma no branch
             assert attributes["patch_url"] is None or isinstance(attributes["patch_url"], (str, unicode)), attributes["patch_url"]
             self._patch_url = attributes["patch_url"]
+        if "review_comment_url" in attributes:  # pragma no branch
+            assert attributes["review_comment_url"] is None or isinstance(attributes["review_comment_url"], (str, unicode)), attributes["review_comment_url"]
+            self._review_comment_url = attributes["review_comment_url"]
         if "review_comments" in attributes:  # pragma no branch
             assert attributes["review_comments"] is None or isinstance(attributes["review_comments"], (int, long)), attributes["review_comments"]
             self._review_comments = attributes["review_comments"]
+        if "review_comments_url" in attributes:  # pragma no branch
+            assert attributes["review_comments_url"] is None or isinstance(attributes["review_comments_url"], (str, unicode)), attributes["review_comments_url"]
+            self._review_comments_url = attributes["review_comments_url"]
         if "state" in attributes:  # pragma no branch
             assert attributes["state"] is None or isinstance(attributes["state"], (str, unicode)), attributes["state"]
             self._state = attributes["state"]
@@ -574,4 +649,4 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             self._url = attributes["url"]
         if "user" in attributes:  # pragma no branch
             assert attributes["user"] is None or isinstance(attributes["user"], dict), attributes["user"]
-            self._user = None if attributes["user"] is None else github.NamedUser.NamedUser(self._requester, attributes["user"], completed=False)
+            self._user = None if attributes["user"] is None else github.NamedUser.NamedUser(self._requester, self._headers, attributes["user"], completed=False)
